"use strict"

jQuery(document).ready(function ($) {
    $(document).on('click', '.wgbl-add-condition', function () {
        let rule = $(this).closest('.wgbl-rule-item');
        let ruleID = rule.attr('data-id');
        let conditionID = parseInt($(this).closest('.wgbl-rule-item').find('.wgbl-condition-items .wgbl-rule-item-sortable-item').length);
        rule.find('.wgbl-condition-items').append(wgblRuleConditionsNewItem(ruleID, conditionID));
        wgblResetData();
        wgblSetSortableItems();
    });

    $(document).on('change', '.wgbl-rule-condition-item', function () {
        let $this = $(this);
        setTimeout(function () {
            if ($.inArray($this.val(), [
                'date',
                'time',
                'date_time',
                'days_of_week',
            ]) === -1) {
                $this.closest('.wgbl-form-group').find('.select2-selection__rendered').css({ color: "red" });
            } else {
                $this.closest('.wgbl-form-group').find('.select2-selection__rendered').css({ color: "#2c3338" });
            }
        }, 200);

        let ruleID = $this.closest('.wgbl-rule-item').attr('data-id');
        let conditionID = $this.closest('.wgbl-rule-item-sortable-item').attr('data-id');
        $this.closest('.wgbl-rule-item-sortable-item').find('.wgbl-condition-extra-fields').html(wgblSetConditionsFields($this.val(), ruleID, conditionID));
        wgblResetData();
    });

    $(document).on('click', '.wgbl-condition-delete', function () {
        let ruleItem = $(this).closest('.wgbl-rule-item');
        $(this).closest('.wgbl-rule-item-sortable-item').remove();
        wgblConditionsFixPriority(ruleItem);
    });

    $(document).on('change', '.wgbl-condition-user-meta-field-type', function () {
        let ruleID = $(this).closest('.wgbl-rule-item').attr('data-id');
        let conditionID = $(this).closest('.wgbl-rule-item-sortable-item').attr('data-id');
        $(this).closest('.wgbl-condition-extra-fields').find('.wgbl-condition-extra-fields-col-4').html(wgblGetConditionUserMetaFieldTypeFields($(this).val(), ruleID, conditionID))
    });

    $(document).on('change', '.wgbl-condition-coupons-applied-type', function () {
        let ruleID = $(this).closest('.wgbl-rule-item').attr('data-id');
        let conditionID = $(this).closest('.wgbl-rule-item-sortable-item').attr('data-id');
        $(this).closest('.wgbl-condition-extra-fields').find('.wgbl-condition-extra-fields-col-4').html(wgblGetConditionCouponsAppliedTypeFields($(this).val(), ruleID, conditionID));
        wgblResetData();
    });
})

function wgblGetConditionCouponsAppliedTypeFields(type, ruleID, conditionID) {
    let output;
    switch (type) {
        case 'at_least_one':
        case 'all':
        case 'only':
        case 'none':
            output = '<select name="rule[' + ruleID + '][condition][' + conditionID + '][coupons][]" class="wgbl-select2-coupons" data-type="select2" data-placeholder="Select ..." required multiple></select>';
            break;
        default:
            output = '';
    }
    return output;
}

function wgblGetConditionUserMetaFieldTypeFields(type, ruleID, conditionID) {
    let output;
    switch (type) {
        case 'contains':
        case 'does_not_contain':
        case 'does_not_contain':
        case 'begins_with':
        case 'ends_with':
        case 'equals':
        case 'does_not_equal':
        case 'less_than':
        case 'less_or_equal_to':
        case 'more_than':
        case 'more_or_equal':
            output = '<input type="text" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="Value ..." required>';
            break;
        default:
            output = '';
    }
    return output;
}

function wgblRuleConditionsNewItem(ruleID, conditionID, type = '') {
    let output = '' +
        '<div class="wgbl-rule-item-sortable-item" data-id="' + conditionID + '">' +
        '<button type="button" class="wgbl-rule-item-condition-sortable-btn wgbl-button-tr wgbl-float-left"><i class="dashicons dashicons-menu"></i></button>' +
        '<div class="wgbl-w20p">' +
        '<div class="wgbl-form-group">' +
        '<select name="rule[' + ruleID + '][condition][' + conditionID + '][type]" class="wgbl-rule-condition-item wgbl-select2-grouped" data-type="select2">' +
        '<optgroup label="Date & Times">' +
        '<option value="date">Date</option>' +
        '<option value="time">Time</option>' +
        '<option value="date_time">Date & Time</option>' +
        '<option value="days_of_week">Days of week</option>' +
        '</optgroup>' +
        '<optgroup label="Cart - Pro version">' +
        '<option value="cart_subtotal">Cart subtotal</option>' +
        '<option value="cart_total_weight">Cart total weight</option>' +
        '<option value="cart_total_quantity">Cart Total Quantity</option>' +
        '<option value="cart_item_count">Cart item count</option>' +
        '<option value="coupons_applied">Coupons applied</option>' +
        '</optgroup>' +
        '<optgroup label="Cart Items - Pro version">' +
        '<option value="cart_items_products">Cart items - Products</option>' +
        '<option value="cart_items_variations">Cart items - Variations</option>' +
        '<option value="cart_items_categories">Cart items - Categories</option>' +
        '<option value="cart_items_attributes">Cart items - Attributes</option>' +
        '<option value="cart_items_tags">Cart items - Tags</option>' +
        '<option value="cart_items_shipping_classes">Cart items - Shipping Classes</option>' +
        '</optgroup>' +
        '<optgroup label="Cart Items - Quantity - Pro version">' +
        '<option value="cart_item_quantity_products">Cart item quantity - Products</option>' +
        '<option value="cart_item_quantity_variations">Cart item quantity - Variations</option>' +
        '<option value="cart_item_quantity_categories">Cart item quantity - Categories</option>' +
        '<option value="cart_item_quantity_attributes">Cart item quantity - Attributes</option>' +
        '<option value="cart_item_quantity_tags">Cart item quantity - Tags</option>' +
        '<option value="cart_item_quantity_shipping_classes">Cart item quantity - Shipping Classes</option>' +
        '</optgroup>' +
        '<optgroup label="Cart Items - Subtotal - Pro version">' +
        '<option value="cart_item_subtotal_products">Cart item subtotal - Products</option>' +
        '<option value="cart_item_subtotal_variations">Cart item subtotal - Variations</option>' +
        '<option value="cart_item_subtotal_categories">Cart item subtotal - Categories</option>' +
        '<option value="cart_item_subtotal_attributes">Cart item subtotal - Attributes</option>' +
        '<option value="cart_item_subtotal_tags">Cart item subtotal - Tags</option>' +
        '<option value="cart_item_subtotal_shipping_classes">Cart item subtotal - Shipping Classes</option>' +
        '</optgroup>' +
        '<optgroup label="Customer - Pro version">' +
        '<option value="customer">Customer</option>' +
        '<option value="user_role">User role</option>' +
        '<option value="user_capability">User Capability</option>' +
        '<option value="user_meta">User Meta</option>' +
        '<option value="is_logged_in">Is logged in</option>' +
        '</optgroup>' +
        '<optgroup label="Customer - Value - Pro version">' +
        '<option value="spent_total">Spent - Total</option>' +
        '<option value="spent_average_per_order">Spent - Average per order</option>' +
        '<option value="spent_last_order">Spent - Last order</option>' +
        '<option value="order_count">Order count</option>' +
        '<option value="last_order">Last Order</option>' +
        '<option value="customer_review_count_lite">Customer review count</option>' +
        '</optgroup>' +
        '<optgroup label="Purchase History - Pro version">' +
        '<option value="purchased_products">Purchased - Products</option>' +
        '<option value="purchased_variations">Purchased - Variations</option>' +
        '<option value="purchased_categories">Purchased - Categories</option>' +
        '<option value="purchased_attributes">Purchased - Attributes</option>' +
        '<option value="purchased_tags">Purchased - Tags</option>' +
        '</optgroup>' +
        '<optgroup label="Purchase History - Quantity - Pro version">' +
        '<option value="quantity_purchased_products">Quantity purchased - Products</option>' +
        '<option value="quantity_purchased_variations">Quantity purchased - Variations</option>' +
        '<option value="quantity_purchased_categories">Quantity purchased - Categories</option>' +
        '<option value="quantity_purchased_attributes">Quantity purchased - Attributes</option>' +
        '<option value="quantity_purchased_tags">Quantity purchased - Tags</option>' +
        '</optgroup>' +
        '<optgroup label="Purchase History - Value - Pro version">' +
        '<option value="value_purchased_products">Value purchased - Products</option>' +
        '<option value="value_purchased_variations">Value purchased - Variations</option>' +
        '<option value="value_purchased_categories">Value purchased - Categories</option>' +
        '<option value="value_purchased_attributes">Value purchased - Attributes</option>' +
        '<option value="value_purchased_tags">Value purchased - Tags</option>' +
        '</optgroup>' +
        '</select>' +
        '</div>' +
        '</div>' +
        '<div class="wgbl-condition-extra-fields">' +
        wgblSetConditionsFields((type) ? type : 'date', ruleID, conditionID) +
        '</div> ' +
        '<button type="button" class="wgbl-button-tr wgbl-float-right wgbl-condition-delete"><i class="dashicons dashicons-no-alt"></i></button>' +
        '</div>' +
        '';
    return output;
}

function wgblRuleConditions(ruleID) {
    //
}

function wgblSetConditionsFields(type, ruleID, conditionID) {
    let output = "";
    switch (type) {
        case 'date':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="from">From</option>' +
                '<option value="to">To</option>' +
                '<option value="specific_date">Specific Date</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<input name="rule[' + ruleID + '][condition][' + conditionID + '][value]" type="text" class="wgbl-datepicker" placeholder="Select ..." required autocomplete="off">' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'time':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="from">From</option>' +
                '<option value="to">To</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<input name="rule[' + ruleID + '][condition][' + conditionID + '][value]" type="text" class="wgbl-timepicker" placeholder="Select ..." required autocomplete="off">' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'date_time':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="from">From</option>' +
                '<option value="to">To</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<input name="rule[' + ruleID + '][condition][' + conditionID + '][value]" type="text" class="wgbl-datetimepicker" placeholder="Select ..." required autocomplete="off">' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'days_of_week':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="in_list">in list</option>' +
                '<option value="not_in_list">not in list</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][value][]" class="wgbl-select2" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '<option value="0">Sunday</option>' +
                '<option value="1">Monday</option>' +
                '<option value="2">Tuesday</option>' +
                '<option value="3">Wednesday</option>' +
                '<option value="4">Thursday</option>' +
                '<option value="5">Friday</option>' +
                '<option value="6">Saturday</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_subtotal':
        case 'cart_total_weight':
        case 'cart_total_quantity':
        case 'cart_item_count':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<input name="rule[' + ruleID + '][condition][' + conditionID + '][value]" type="number" min="0" placeholder="0.00" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'coupons_applied':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]" class="wgbl-condition-coupons-applied-type">' +
                '<option value="at_least_one_any">at least one of any</option>' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '<option value="none_at_all">none at all</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<div class="wgbl-condition-extra-fields-col-4"></div>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_items_products':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][products][]" class="wgbl-select2-products" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_items_variations':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][variations][]" class="wgbl-select2-variations" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_items_categories':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][categories][]" class="wgbl-select2-categories" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_items_attributes':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][attributes][]" class="wgbl-select2-attributes" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_items_tags':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][tags][]" class="wgbl-select2-tags" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_items_shipping_classes':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][shipping_classes][]" class="wgbl-select2-shipping_classes" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_quantity_products':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][products][]" class="wgbl-select2-products" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_quantity_variations':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][variations][]" class="wgbl-select2-variations" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_quantity_categories':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][categories][]" class="wgbl-select2-categories" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_quantity_attributes':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][attributes][]" class="wgbl-select2-attributes" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_quantity_tags':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][tags][]" class="wgbl-select2-tags" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_quantity_shipping_classes':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][shipping_classes][]" class="wgbl-select2-shipping_classes" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_subtotal_products':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][products][]" class="wgbl-select2-products" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_subtotal_variations':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][variations][]" class="wgbl-select2-variations" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_subtotal_categories':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][categories][]" class="wgbl-select2-categories" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_subtotal_attributes':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][attributes][]" class="wgbl-select2-attributes" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_subtotal_tags':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][tags][]" class="wgbl-select2-tags" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'cart_item_subtotal_shipping_classes':
            output = '' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][shipping_classes][]" class="wgbl-select2-shipping_classes" data-type="select2" data-placeholder="Select values ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w32p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'customer':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="in_list">in list</option>' +
                '<option value="not_in_list">not in list</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][customers][]" class="wgbl-select2-customers" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'user_role':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="in_list">in list</option>' +
                '<option value="not_in_list">not in list</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][user_roles][]" class="wgbl-select2-user-roles" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'user_capability':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="in_list">in list</option>' +
                '<option value="not_in_list">not in list</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][user_capabilities][]" class="wgbl-select2-user-capabilities" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'user_meta':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<input name="rule[' + ruleID + '][condition][' + conditionID + '][meta_field_key]" type="text" placeholder="meta field key" required>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]" class="wgbl-condition-user-meta-field-type">' +
                '<option value="is_empty">is empty</option>' +
                '<option value="is_not_empty">is not empty</option>' +
                '<option value="contains">contains</option>' +
                '<option value="does_not_contain">does not contain</option>' +
                '<option value="begins_with">begins with</option>' +
                '<option value="ends_with">ends with</option>' +
                '<option value="equals">equals</option>' +
                '<option value="does_not_equal">does not equal</option>' +
                '<option value="less_than">less than</option>' +
                '<option value="less_or_equal_to">less or equal to</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="more_or_equal">more or equal to</option>' +
                '<option value="is_checked">is checked</option>' +
                '<option value="is_not_checked">is not checked</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<div class="wgbl-condition-extra-fields-col-4"></div>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'is_logged_in':
            output = '' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][value]" required>' +
                '<option value="yes">Yes</option>' +
                '<option value="no">No</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'spent_total':
        case 'spent_average_per_order':
        case 'order_count':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][time]" required>' +
                getAllTimes() +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0.00" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'spent_last_order':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0.00" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'last_order':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="later">within past</option>' +
                '<option value="earlier">earlier than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][time]" required>' +
                getAllTimes() +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'customer_review_count_lite':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w70p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'purchased_products':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][time]" required>' +
                getAllTimes() +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][products][]" class="wgbl-select2-products" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'purchased_variations':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][time]" required>' +
                getAllTimes() +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][variations][]" class="wgbl-select2-variations" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'purchased_categories':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][time]" required>' +
                getAllTimes() +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][categories][]" class="wgbl-select2-categories" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'purchased_attributes':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][time]" required>' +
                getAllTimes() +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][attributes][]" class="wgbl-select2-attributes" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'purchased_tags':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][time]" required>' +
                getAllTimes() +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least_one">at least one of selected</option>' +
                '<option value="all">all of selected</option>' +
                '<option value="only">only selected</option>' +
                '<option value="none">none of selected</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][tags][]" class="wgbl-select2-tags" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'quantity_purchased_products':
        case 'value_purchased_products':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][products][]" class="wgbl-select2-products" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'quantity_purchased_variations':
        case 'value_purchased_variations':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][variations][]" class="wgbl-select2-variations" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'quantity_purchased_categories':
        case 'value_purchased_categories':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][categories][]" class="wgbl-select2-categories" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'quantity_purchased_attributes':
        case 'value_purchased_attributes':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][attributes][]" class="wgbl-select2-attributes" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
        case 'quantity_purchased_tags':
        case 'value_purchased_tags':
            output = '' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][tags][]" class="wgbl-select2-tags" data-type="select2" data-placeholder="Select ..." multiple required>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<select name="rule[' + ruleID + '][condition][' + conditionID + '][method_option]">' +
                '<option value="at_least">at least</option>' +
                '<option value="more_than">more than</option>' +
                '<option value="not_more_than">not more than</option>' +
                '<option value="less_than">less than</option>' +
                '</select>' +
                '</div>' +
                '</div>' +
                '<div class="wgbl-w30p">' +
                '<div class="wgbl-form-group">' +
                '<input type="number" min="0" name="rule[' + ruleID + '][condition][' + conditionID + '][value]" placeholder="0" required>' +
                '</div>' +
                '</div>' +
                '';
            break;
    }

    return output;
}

function getAllTimes() {
    let output = '' +
        '<optgroup label="All time">' +
        '<option value="all_time">all time</option>' +
        '</optgroup>' +
        '<optgroup label="Current">' +
        '<option value="current_day">current day</option>' +
        '<option value="current_week">current week</option>' +
        '<option value="current_month">current month</option>' +
        '<option value="current_year">current year</option>' +
        '</optgroup>' +
        '<optgroup label="Days">' +
        '<option value="1_day">1 day</option>' +
        '<option value="2_day">2 days</option>' +
        '<option value="3_day">3 days</option>' +
        '<option value="4_day">4 days</option>' +
        '<option value="5_day">5 days</option>' +
        '<option value="6_day">6 days</option>' +
        '</optgroup>' +
        '<optgroup label="Weeks">' +
        '<option value="1_week">1 week</option>' +
        '<option value="2_week">2 weeks</option>' +
        '<option value="3_week">3 weeks</option>' +
        '<option value="4_week">4 weeks</option>' +
        '</optgroup>' +
        '<optgroup label="Months">' +
        '<option value="1_month">1 month</option>' +
        '<option value="2_month">2 months</option>' +
        '<option value="3_month">3 months</option>' +
        '<option value="4_month">4 months</option>' +
        '<option value="5_month">5 months</option>' +
        '<option value="6_month">6 months</option>' +
        '<option value="7_month">7 months</option>' +
        '<option value="8_month">8 months</option>' +
        '<option value="9_month">9 months</option>' +
        '<option value="10_month">10 months</option>' +
        '<option value="11_month">11 months</option>' +
        '<option value="12_month">12 months</option>' +
        '</optgroup>' +
        '<optgroup label="Years">' +
        '<option value="2_year">2 years</option>' +
        '<option value="3_year">3 years</option>' +
        '<option value="4_year">4 years</option>' +
        '<option value="5_year">5 years</option>' +
        '<option value="6_year">6 years</option>' +
        '<option value="7_year">7 years</option>' +
        '<option value="8_year">8 years</option>' +
        '<option value="9_year">9 years</option>' +
        '<option value="10_year">10 years</option>' +
        '</optgroup>' +
        '';
    return output;
}