<?php

namespace wgbl\classes\bootstrap;

use wgbl\classes\controllers\Rules_Controller;
use wgbl\classes\controllers\Reports_Controller;
use wgbl\classes\controllers\WGBL_Ajax;
use wgbl\classes\controllers\WGBL_Post;
use wgbl\classes\repositories\Order;
use wgbl\classes\repositories\Rule;
use wgbl\classes\repositories\Setting;

class WGBL
{
    private static $instance;

    public static function init()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }
    }

    private function __construct()
    {
        if (!current_user_can('manage_woocommerce')) {
            return;
        }
        add_action('admin_menu', [$this, 'add_menu']);
        add_action('admin_enqueue_scripts', [$this, 'load_assets']);
        WGBL_Ajax::register_callback();
        WGBL_Post::register_callback();
        (new WGBL_Custom_Queries())->init();

        $settings_repository = Setting::get_instance();
        if (!$settings_repository->has_settings()) {
            $settings_repository->set_default_settings();
        }
    }

    public static function wgbl_woocommerce_required()
    {
        include WGBL_VIEWS_DIR . 'alerts/wgbl_woocommerce_required.php';
    }

    public static function wgbl_wp_init()
    {
        // set plugin version
        $version = get_option('wgbl_version');
        if (empty($version) || $version != WGBL_VERSION) {
            update_option('wgbl_version', WGBL_VERSION);
        }

        // load textdomain
        load_plugin_textdomain('ithemeland-free-gifts-for-woocommerce-lite', false, WGBL_LANGUAGES_DIR);
    }

    public function add_menu()
    {
        add_menu_page(esc_html__('Woo Free Gift', WGBL_NAME), esc_html__('Woo Free Gift', WGBL_NAME), 'manage_woocommerce', 'wgbl', [new Rules_Controller, 'index'], WGBL_IMAGES_URL . 'wgbl_icon.svg', 2);
        add_submenu_page('wgbl', esc_html__('Rules | Settings', WGBL_NAME), esc_html__('Rules | Settings', WGBL_NAME), 'manage_woocommerce', 'wgbl');
        add_submenu_page('wgbl', esc_html__('Reports', WGBL_NAME), esc_html__('Reports', WGBL_NAME), 'manage_woocommerce', 'wgbl-reports', [new Reports_Controller, 'index']);
    }

    public function load_assets($page)
    {
        if (!empty($_GET['page']) && in_array($_GET['page'], ['wgbl', 'wgbl-reports'])) {
            $rule_repository = Rule::get_instance();
            // Styles
            wp_enqueue_style('wgbl-reset', WGBL_CSS_URL . 'common/reset.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-LineIcons', WGBL_CSS_URL . 'common/LineIcons.min.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-select2', WGBL_CSS_URL . 'common/select2.min.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-tipsy', WGBL_CSS_URL . 'common/jquery.tipsy.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-sweetalert', WGBL_CSS_URL . 'common/sweetalert.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-datetimepicker', WGBL_CSS_URL . 'common/jquery.datetimepicker.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-main', WGBL_CSS_URL . 'common/style.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-responsive', WGBL_CSS_URL . 'common/responsive.css', [], WGBL_VERSION);

            // Scripts
            wp_enqueue_script('wgbl-functions', WGBL_JS_URL . 'common/functions.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-tipsy', WGBL_JS_URL . 'common/jquery.tipsy.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-datetimepicker', WGBL_JS_URL . 'common/jquery.datetimepicker.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-select2', WGBL_JS_URL . 'common/select2.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-sweetalert', WGBL_JS_URL . 'common/sweetalert.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-main', WGBL_JS_URL . 'common/main.js', ['jquery'], WGBL_VERSION);
            wp_localize_script('wgbl-main', 'WGBL_DATA', [
                'ajax_url' => admin_url('admin-ajax.php'),
                'wp_nonce' => wp_create_nonce(),
                'ruleMethods' => $rule_repository->get_rule_methods(),
                'ruleMethodOptions' => $rule_repository->get_rule_method_options(),
                'loadingImage' => '<span class="wgbl-button-loading"><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="34px" height="34px" viewBox="0 0 100 100" preserveAspectRatio="xMidYMid"><rect x="17.5" y="30" width="15" height="40" fill="#ffffff"><animate attributeName="y" repeatCount="indefinite" dur="0.8s" calcMode="spline" keyTimes="0;0.5;1" values="18;30;30" keySplines="0 0.5 0.5 1;0 0.5 0.5 1" begin="-0.16s"></animate><animate attributeName="height" repeatCount="indefinite" dur="0.8s" calcMode="spline" keyTimes="0;0.5;1" values="64;40;40" keySplines="0 0.5 0.5 1;0 0.5 0.5 1" begin="-0.16s"></animate></rect><rect x="42.5" y="30" width="15" height="40" fill="#ffffff"><animate attributeName="y" repeatCount="indefinite" dur="0.8s" calcMode="spline" keyTimes="0;0.5;1" values="20.999999999999996;30;30" keySplines="0 0.5 0.5 1;0 0.5 0.5 1" begin="-0.08s"></animate><animate attributeName="height" repeatCount="indefinite" dur="0.8s" calcMode="spline" keyTimes="0;0.5;1" values="58.00000000000001;40;40" keySplines="0 0.5 0.5 1;0 0.5 0.5 1" begin="-0.08s"></animate></rect><rect x="67.5" y="30" width="15" height="40" fill="#ffffff"><animate attributeName="y" repeatCount="indefinite" dur="0.8s" calcMode="spline" keyTimes="0;0.5;1" values="20.999999999999996;30;30" keySplines="0 0.5 0.5 1;0 0.5 0.5 1"></animate><animate attributeName="height" repeatCount="indefinite" dur="0.8s" calcMode="spline" keyTimes="0;0.5;1" values="58.00000000000001;40;40" keySplines="0 0.5 0.5 1;0 0.5 0.5 1"></animate></rect></svg></span>',
            ]);
        }

        // load assets for rules | settings 
        if (!empty($_GET['page']) && $_GET['page'] == 'wgbl') {
            // Styles
            wp_enqueue_style('wgbl-rules-main', WGBL_CSS_URL . 'rules/style.css', [], WGBL_VERSION);

            // Scripts
            wp_enqueue_script('wgbl-rules-form-conditions', WGBL_JS_URL . 'rules/form_data/common/conditions.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-form-get', WGBL_JS_URL . 'rules/form_data/common/get.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-form-products_buy', WGBL_JS_URL . 'rules/form_data/common/products_buy.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-form-quantities', WGBL_JS_URL . 'rules/form_data/common/quantities.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-form-simple', WGBL_JS_URL . 'rules/form_data/simple.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-form-buy-x-get-x', WGBL_JS_URL . 'rules/form_data/buy_x_get_x.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-form-buy-x-get-y', WGBL_JS_URL . 'rules/form_data/buy_x_get_y.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-form-subtotal', WGBL_JS_URL . 'rules/form_data/subtotal.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-functions', WGBL_JS_URL . 'rules/functions.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-rules-main', WGBL_JS_URL . 'rules/main.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('jquery-ui-sortable');
        }

        // load assets for reports
        if (!empty($_GET['page']) && $_GET['page'] == 'wgbl-reports') {
            // Styles
            wp_enqueue_style('wgbl-reports-bootstrap', WGBL_CSS_URL . 'common/bootstrap.dataTables.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-reports-datatable', WGBL_CSS_URL . 'common/dataTables.bootstrap4.min.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-reports-daterangepicker', WGBL_CSS_URL . 'common/daterangepicker.css', [], WGBL_VERSION);
            wp_enqueue_style('wgbl-reports-main', WGBL_CSS_URL . 'reports/style.css', [], WGBL_VERSION);

            // Scripts
            wp_enqueue_script('wgbl-reports-amcharts-core', WGBL_JS_URL . 'common/amcharts/core.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-amcharts-charts', WGBL_JS_URL . 'common/amcharts/charts.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-amcharts-animated', WGBL_JS_URL . 'common/amcharts/animated.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-datatable', WGBL_JS_URL . 'common/jquery.dataTables.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-datatable-buttons', WGBL_JS_URL . 'common/dataTables.buttons.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-pdfmake', WGBL_JS_URL . 'common/pdfmake.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-jszip', WGBL_JS_URL . 'common/jszip.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-vfs-fonts', WGBL_JS_URL . 'common/vfs_fonts.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-buttons-html5', WGBL_JS_URL . 'common/buttons.html5.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-buttons-print', WGBL_JS_URL . 'common/buttons.print.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-buttons-flash', WGBL_JS_URL . 'common/buttons.flash.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-moment', WGBL_JS_URL . 'common/moment.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-daterangepicker', WGBL_JS_URL . 'common/daterangepicker.min.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-functions', WGBL_JS_URL . 'reports/functions.js', ['jquery'], WGBL_VERSION);
            wp_enqueue_script('wgbl-reports-main', WGBL_JS_URL . 'reports/main.js', ['jquery'], WGBL_VERSION);

            wp_localize_script('wgbl-reports-main', 'WGBL_REPORTS_DATA', $this->get_reports_js_data());
        }
    }

    public static function wp_loaded()
    {
        //    
    }

    public static function activate()
    {
        //
    }

    public static function deactivate()
    {
        //
    }

    private function get_reports_js_data()
    {
        $order_repository = Order::get_instance();
        return [
            'subPage' => (!empty($_GET['sub-page'])) ? sanitize_text_field($_GET['sub-page']) : 'dashboard',
            'subMenu' => (!empty($_GET['sub-menu'])) ? sanitize_text_field($_GET['sub-menu']) : '',
            'orderStatuses' => $order_repository->get_order_statuses(),
            'mainUrl' => WGBL_REPORTS_PAGE,
            'dataTableOptions' => [
                'responsive' => true,
                'dom' => 'lBfrtip',
                'buttons' => [
                    [
                        'buttons' => ['csv', 'excel', 'pdf', 'print'],
                        'text' => '<i class="lni lni-cloud-download"></i>',
                        'extend' => 'collection',
                    ]
                ]
            ]
        ];
    }
}
